@@ -6,6 +6,11 @@ knitr::opts_chunk$set(
 
 ## ---- include=FALSE, echo=FALSE-----------------------------------------------
 oldpar <- par()
+# if (!nzchar(Sys.getenv("_R_CHECK_LIMIT_CORES_", ""))) {
+#   ## Possible values: 'TRUE' 'false', 'warn', 'error'
+#   Sys.setenv("_R_CHECK_LIMIT_CORES_" = "TRUE")
+# }
+Sys.setenv("OMP_NUM_THREADS" = 1)
 
 ## -----------------------------------------------------------------------------
 library(ATNr)
@@ -13,6 +18,12 @@ set.seed(123)
 n_species <- 20 # number of species
 conn <- 0.3 # connectance
 fw <- create_niche_model(n_species, conn)
+# The number of basal species can be calculated:
+n_basal <- sum(colSums(fw) == 0)
+
+## -----------------------------------------------------------------------------
+TL = TroLev(fw) #trophic levels
+masses <- 1e-2 * 10 ^ (TL - 1)
 
 ## -----------------------------------------------------------------------------
 n_species <- 20
@@ -36,8 +47,8 @@ model_scaled <- create_model_Scaled(n_species, n_basal, masses, fw)
 model_unscaled <- create_model_Unscaled(n_species, n_basal, masses, fw)
 
 ## -----------------------------------------------------------------------------
-# updating the hill coefficient in the Unscaled_nuts model:
-model_unscaled_nuts$q <- 1.4
+# updating the hill coefficient of consumers in the Unscaled_nuts model:
+model_unscaled_nuts$q <- rep(1.4, model_unscaled_nuts$nb_s - model_unscaled_nuts$nb_s)
 # Changing the assimilation efficiencies of all species to 0.5 in the Scaled model:
 model_scaled$e = rep(0.5, model_scaled$nb_s)
 # print the different fields that can be updated and their values:
@@ -46,16 +57,13 @@ model_scaled$e = rep(0.5, model_scaled$nb_s)
 ## -----------------------------------------------------------------------------
 # for a model created by create_model_Unscaled_nuts():
 model_unscaled_nuts <- initialise_default_Unscaled_nuts(model_unscaled_nuts, L)
-model_unscaled_nuts$initialisations()
 # for a model created by create_model_Scaled():
 model_scaled <- initialise_default_Scaled(model_scaled)
-model_scaled$initialisations()
 # for a model created by create_model_Unscaled():
 model_unscaled <- initialise_default_Unscaled(model_unscaled)
-model_unscaled$initialisations()
 
 ## ----wrappers-----------------------------------------------------------------
-biomasses <- masses ^ -0.75 * 1e1 # starting biomasses
+biomasses <-runif(n_species, 2, 3) # starting biomasses
 biomasses <- append(runif(3, 20, 30), biomasses) # nutrient concentration
 # defining the desired integration time
 times <- seq(0, 1500, 5)
@@ -63,6 +71,7 @@ sol <- lsoda_wrapper(times, biomasses, model_unscaled_nuts)
 
 ## ----deSolve------------------------------------------------------------------
 # running simulations for the Schneider model
+model_unscaled_nuts$initialisations()
 sol <- deSolve::lsoda(
   biomasses,
   times,
@@ -143,9 +152,9 @@ for (t in temperatures){
   # Therefore, it is not needed to create a new model object
   # TO reinitialise the different parameters is enough
   model <- initialise_default_Unscaled_nuts(model, L, temperature = t)
-  model$q <- 1.2
+  # updating the value of q, same for all consumers
+  model$q = rep(1.4, n_species - n_basal)
   model$S <- rep(10, n_nut)
-  model$initialisations()
   # running simulations for the Schneider model:
   sol <- lsoda_wrapper(times, biomasses, model, verbose = FALSE)
   # retrieve the number of species that went extinct before the end of the
@@ -193,7 +202,6 @@ for (scal in scaling) {
   mod0 <- initialise_default_Unscaled(mod0, temperature = 0)
   mod0$c <- rep(0, mod0$nb_s - mod0$nb_b)
   mod0$alpha <- diag(mod0$nb_b)
-  mod0$initialisations()
   
   mod40 <- create_model_Unscaled(nb_s = S,
                                nb_b = sum(colSums(fw) == 0),
@@ -202,7 +210,6 @@ for (scal in scaling) {
   mod40 <- initialise_default_Unscaled(mod40, temperature = 40)
   mod40$c <- rep(0, mod40$nb_s - mod40$nb_b)
   mod40$alpha <- diag(mod40$nb_b)
-  mod40$initialisations()
   
   times <- seq(1, 1e9, by = 1e7)
   
@@ -240,8 +247,7 @@ mod <- create_model_Scaled(nb_s = S,
                            BM = masses,
                            fw = fw)
 mod <- initialise_default_Scaled(mod)
-mod$initialisations()
-times <- seq(0, 500, by = 2)
+times <- seq(0, 300, by = 2)
 biomasses <- runif(S, 2, 3) # starting biomasses
 
 ## ----delmas 2-----------------------------------------------------------------
@@ -276,7 +282,6 @@ model_unscaled_nuts$nb_s #this is the model parameter
 ## -----------------------------------------------------------------------------
 times <- seq(0, 15000, 150)
 model_unscaled_nuts$nb_s = 40
-model_unscaled_nuts$initialisations()
 # this will return an error :
 # sol <- lsoda_wrapper(times, biomasses, model_schneider)
 
@@ -294,7 +299,6 @@ fw[fw > 0] <- 1
 model_unscaled_nuts <- create_model_Unscaled_nuts(nb_s, nb_b, nb_n, masses, fw)
 model_unscaled_nuts <- initialise_default_Unscaled_nuts(model_unscaled_nuts, L)
 model_unscaled_nuts$BM <- sqrt(model_unscaled_nuts$BM) # we change body masses within the model
-model_unscaled_nuts$initialisations()
 sol <- lsoda_wrapper(seq(1, 5000, 50), biomasses, model_unscaled_nuts)
 par(mar = c(4, 4, 1, 1))
 plot_odeweb(sol, model_unscaled_nuts$nb_s)
@@ -312,20 +316,6 @@ fw[fw > 0] <- 1
 model_unscaled_nuts <- create_model_Unscaled_nuts(nb_s, nb_b, nb_n, masses, fw)
 model_unscaled_nuts <- initialise_default_Unscaled_nuts(model_unscaled_nuts, L)
 # safely run the integration:
-model_unscaled_nuts$initialisations()
-sol <- lsoda_wrapper(times, biomasses, model_unscaled_nuts)
-
-## ----mistake 3----------------------------------------------------------------
-nb_s <- 30
-masses <- sort(10 ^ runif(nb_s, 2, 6)) #body mass of species
-L <- create_Lmatrix(masses, nb_b, Ropt = 50)
-L[, 1:nb_b] <- 0
-fw <- L
-fw[fw > 0] <- 1
-# create a new object:
-model_unscaled_nuts <- create_model_Unscaled_nuts(nb_s, nb_b, nb_n, masses, fw)
-model_unscaled_nuts <- initialise_default_Unscaled_nuts(model_unscaled_nuts, L)
-model_unscaled_nuts$initialisations() # commenting this line will lead to wrong results.
 sol <- lsoda_wrapper(times, biomasses, model_unscaled_nuts)
 
 ## ----mistake 4----------------------------------------------------------------
@@ -349,6 +339,53 @@ model_1$q = 1.8
 # this also updated the value in model_2:
 model_2$q
 
+## -----------------------------------------------------------------------------
+plus.3 = function(x, useless) {
+  y = x+3
+  useless = useless + 1
+  return(y)
+}
+
+useless = 4:10
+useless2 = useless
+x = sapply(1:5, plus.3, useless)
+# the useless variable was not modified:
+useless == useless2
+
+## -----------------------------------------------------------------------------
+
+n_species <- 20
+n_basal <- 5
+n_cons = n_species - n_basal
+n_nut <- 2
+masses <- 10 ^ c(sort(runif(n_basal, 0, 3)),
+                 sort(runif(n_species - n_basal, 2, 5)))
+L <- create_Lmatrix(masses, n_basal, Ropt = 100, gamma = 2, th = 0.01)
+fw <- L
+fw[fw > 0] <- 1
+model <- create_model_Unscaled_nuts(n_species, n_basal, n_nut, masses, fw)
+model <- initialise_default_Unscaled_nuts(model, L, temperature = 20)
+
+## -----------------------------------------------------------------------------
+# a function that sets all elements of model$b to 0
+a.fun <-  function(x, model){
+  model$b = model$b*0
+  return(x+1)
+}
+
+## ---- eval = FALSE------------------------------------------------------------
+#  x = c(1,2)
+#  sum(model$b)
+#  y = lapply(x, a.fun, model)
+#  sum(model$b)
+
+## ---- eval = FALSE------------------------------------------------------------
+#  library(parallel)
+#  sum(model$b)
+#  model <- initialise_default_Unscaled_nuts(model, L, temperature = 20)
+#  y = mclapply(x, a.fun, model = model, mc.cores=5)
+#  sum(model$b)
+
 ## ----restore par, include=FALSE, echo=FALSE-----------------------------------
 par(oldpar)
 
